@@ -7,9 +7,25 @@ from urllib.parse import urlparse
 from Crypto.Hash import SHA256
 from httpsig.requests_auth import HTTPSignatureAuth
 from httpsig.utils import HttpSigException
+from requests import Session
 from requests.auth import AuthBase
 
 
+class AuthSession(Session):
+    """Custom Session to handle any auth specific behaviors"""
+
+    def rebuild_auth(self, prepared_request, response):
+        """
+        Monkey-patches original rebuild_auth method which handles auth building
+        for redirects. In cases where we're using any of our StrateosAuthBase
+        classes, we want to always apply our own internal auth logic handlers.
+        """
+        if isinstance(self.auth, StrateosAuthBase):
+            prepared_request.prepare_auth(self.auth)
+        else:
+            super().rebuild_auth(prepared_request, response)
+
+
 class StrateosAuthBase(AuthBase, ABC):
     def __init__(self, api_root):
         self.api_root = api_root
@@ -59,7 +75,7 @@ class StrateosSign(StrateosAuthBase):
         if request.method.upper() in ("PUT", "POST", "PATCH"):
             encoded_body = (
                 request.body
-                if isinstance(request.body, bytes)
+                if (isinstance(request.body, bytes) or request.body is None)
                 else request.body.encode()
             )
             digest = SHA256.new(encoded_body).digest()
